circle.fornac-node, polygon.fornac-node {
  stroke: #ccc;
  stroke-width: 0.8;
  opacity: 1;
  fill: white;
}

path.fornac-directionArrow {
  fill: #777;
  stroke: none;
  stroke-width: 0.8px;
}

g.fornac-plot {
    /* outline: 1px solid red; */
}

circle.fornac-node[base_type="a"] {
  fill: #dbdb8d;
}

circle.fornac-node[base_type="c"] {
  fill: #98df8a;
}

circle.fornac-node[base_type="g"] {
  fill: #ff9896;
}

circle.fornac-node[base_type="u"], circle.fornac-node[base_type="t"] {
  fill: #aec7e8;
}

.fornac-node > text {
     pointer-events: none;
 }

circle.fornac-node[node_type="label"] {
    stroke: transparent;
    stroke-width: 0;
    fill: white;
    display: inline;
}

circle.fornac-node[node_type="protein"] {
    fill: gray;
    fill-opacity: 0.5;
    stroke-width: 4;
}

.fornac-selectedNode > circle.fornac-node {
    stroke: red;
}

text.fornac-nodeLabel {
    font-weight: bold;
    font-family: Tahoma, Geneva, sans-serif;
    font-size: 0.4em;
    color: rgb(100,100,100);
    text-anchor: middle;
    alignment-baseline: middle;
    dominant-baseline: central;
    pointer-events: none;
    -webkit-touch-callout: none;
    -webkit-user-select: none;
    -khtml-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
}

line.fornac-link {
  stroke: #999;
  stroke-opacity: 0.8;
  stroke-width: 2;
}

line.fornac-link[link_type="pseudoknot"] {
    stroke: red;
}

line.fornac-link[link_type="basepair"] {
  stroke: red;
}

line.fornac-link[link_type="intermolecule"] {
  stroke: blue;
}

line.fornac-link[link_type="chain_chain"] {
  stroke-dasharray: 3,3;
}

line.fornac-link[link_type="fake"] {
  stroke: green;
}

text.fornac-plotLabel {
    font-family: Tahoma, Geneva, sans-serif;
    font-weight: bolder;
    font-size: 1.2em;
    fill: rgba(200, 200, 200, 0.5);
    text-anchor: middle;
    alignment-baseline: central;
}

.fornac-transparent {
    fill: transparent;
    stroke-width: 0;
    stroke-opacity: 0;
    opacity: 0;
    visibility: hidden;
    pointer-events: none;
}

.fornac-dragLine {
  stroke: #999;
  stroke-width: 2;
  pointer-events: none;
}

.fornac-mouseEventHelper > .extent {
  fill-opacity: .1;
  stroke: #fff;
  shape-rendering: crispEdges;
}

.d3-context-menu {
	position: absolute;
	display: none;
	background-color: #f2f2f2;
	border-radius: 4px;

	font-family: Arial, sans-serif;
	font-size: 14px;
	min-width: 150px;
	border: 1px solid #d4d4d4;

	z-index:1200;
}

.d3-context-menu ul {
	list-style-type: none;
	margin: 4px 0px;
	padding: 0px;
	cursor: default;
}

.d3-context-menu ul li {
	padding: 4px 16px;

	-webkit-touch-callout: none; /* iOS Safari */
	-webkit-user-select: none;   /* Chrome/Safari/Opera */
	-khtml-user-select: none;    /* Konqueror */
	-moz-user-select: none;      /* Firefox */
	-ms-user-select: none;       /* Internet Explorer/Edge */
	user-select: none;
}

.d3-context-menu ul li:hover {
	background-color: #4677f8;
	color: #fefefe;
}

.d3-context-menu-selected {
	background-color: #4677f8;
	color: #fefefe;
}

/*
	Header
*/

.d3-context-menu ul li.is-header
.d3-context-menu ul li.is-header:hover {
	background-color: #f2f2f2;
	color: #444;
	font-weight: bold;
	font-style: italic;
}

/*
	Disabled
*/

.d3-context-menu ul li.is-disabled
.d3-context-menu ul li.is-disabled:hover {
	background-color: #f2f2f2;
	color: #888;
	cursor: not-allowed;
}

/*
	Divider
*/

.d3-context-menu ul li.is-divider {
	padding: 0px 0px;
}

.d3-context-menu ul li.is-divider:hover {
	background-color: #f2f2f2;
}

.d3-context-menu ul hr {
	border: 0;
    height: 0;
    border-top: 1px solid rgba(0, 0, 0, 0.1);
    border-bottom: 1px solid rgba(255, 255, 255, 0.3);
}

/*# sourceMappingURL=fornac.css.map*/